Tuning

Struct Tuning 

pub struct Tuning { /* private fields */ }

Implementations

Source

impl Tuning

pub fn new() -> Self

pub fn new_key_tuning(pitch: [f64; 128]) -> Self

Create a new key-based tuning with given pitches. The array should contain the pitch of every key in cents.

pub fn new_octave_tuning(pitch: &[f64; 12]) -> Self

Create a new octave-based tuning with given pitches. The array should contains derivation in cents from the well-tempered scale.

For example, if pitches[0] equals -33, then the C-keys will be tuned 33 cents below the well-tempered C.

pub fn as_slice(&self) -> &[f64; 128]

pub fn as_slice_mut(&mut self) -> &mut [f64; 128]